@@ -41,7 +41,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_sphinx_ver ($self) {
-    return $self->cfg->{SPHINX}->{SPHINX_VER} || $ENV->get_dist('pcore-sphinx')->cfg->{SPHINX}->{SPHINX_VER};
+    return $self->cfg->{SPHINX}->{SPHINX_VER} || $ENV->dist('Pcore-Sphinx')->cfg->{SPHINX}->{SPHINX_VER};
 }
 
 # APP
